package com.cpxt.biz.service;

import java.util.List;
import com.cpxt.biz.domain.BizDriver;

/**
 * 司机Service接口
 * 
 * @author YIN
 * @date 2024-12-16
 */
public interface IBizDriverService 
{
    /**
     * 查询司机
     * 
     * @param id 司机主键
     * @return 司机
     */
    public BizDriver selectBizDriverById(Long id);

    /**
     * 查询司机列表
     * 
     * @param bizDriver 司机
     * @return 司机集合
     */
    public List<BizDriver> selectBizDriverList(BizDriver bizDriver);

    /**
     * 新增司机
     * 
     * @param bizDriver 司机
     * @return 结果
     */
    public int insertBizDriver(BizDriver bizDriver);

    /**
     * 修改司机
     * 
     * @param bizDriver 司机
     * @return 结果
     */
    public int updateBizDriver(BizDriver bizDriver);

    /**
     * 批量删除司机
     * 
     * @param ids 需要删除的司机主键集合
     * @return 结果
     */
    public int deleteBizDriverByIds(Long[] ids);

    /**
     * 删除司机信息
     * 
     * @param id 司机主键
     * @return 结果
     */
    public int deleteBizDriverById(Long id);
}
